@@ -1,5 +1,5 @@
 import urllib, urllib2
-from parser import JsDomParser
+from d9t.json.parser import JsDomParser
 
 class GoogleDirections(object):
     """
@@ -39,6 +39,8 @@ class GoogleDirections(object):
             headers = {}
         req = urllib2.Request(url, None, headers)
         res = urllib2.urlopen(req).read()
+        # google sends as iso-8859-1. Recode.
+        res = res.decode("iso-8859-1")
         parser = JsDomParser(res)
         self.result = parser.parse()
         return self
